==> v0.01.zip: hugo/content/en/LPD.md <==
---
title: "LPD/Maustüröffnertag"
date: 2021-02-04T10:06:20+01:00
draft: false
---
## About the Linux Presentation Day (LPD)

Due to the huge success of last year's event, FraLUG is participating in the Maus Türöffner Tag (Mouse Door Opener Day, sorry about the broken translation :-) ) this year once again. As in the years before, the event takes place on October 3rd in Frankfurt.

![LPD](/lpd/maus.png)

The [Linux Presentation Day](https://l-p-d.org/de/start) is an event where people with little or no previous exposure to Linux have the opportunity to gain a first introduction and experience with this open source operating sytem. The aim of this event which is done in collaboration with the Westdeutscher Rundfunk (WDR), the broadcaster who created this kids' show more than forty years ago, is to also introduce children aged 6 or above to this open source operating system.

Multiple presentations will introduce the children in a suitable way to topics such as programming, using Linux and contemporary issues including Raspberry Pies, etc. In doing so, the focus is on hands-on experience rather than classroom-style teaching so that the audience can benefit the most from this. In addition, there will be demo PCs with games, learning software and special Linux distributions for kids.

Apart from this content aimed at kids there will be experts on site who can help with any questions you may have on the subject of Linux and free software in general. We plan to offer a clinic where we can assist you with any questions on installation and configuration topics - feel free to bring your laptop along!

To ensure proper organisation of the day, participation does require a registration prior to the event. This registration is done via the official [Maustüröffnertage website](https://www.wdrmaus.de/extras/tueren_auf.php5) or via email to maus (at) lugfrankfurt.de. Please state the name and age of participating children when registering.

### Program

The schedule for the day is currently in preparation and will be published in September. Please note that this event will last for the whole day; unfortunately a participation at individual times is not possible due to the fact that a specific piece of content depends on its predecessors.

Please note that the language of the talks and general interaction is German. While some of us do speak English, no guarantees are offered to cater for any non-German speaking participants.

### The certificate

Due to the successful participation in last year's event, the WDR has kindly sent us a certificate thanking us:

![LPD](/lpd/Maus2018.png)

==> v0.03.zip: hugo/content/en/LPD.md <==
---
title: "LPD/Maustüröffnertag"
date: 2021-02-04T10:06:20+01:00
draft: false
---
[![German](/ger.png#floatright)](/de/LPD)

## About the Linux Presentation Day (LPD)

Unfortunately, this year's Linux Presentation Day, generally organised in the context of the {{< tabref href="https://www.wdrmaus.de/extras/tueren_auf/infos_besucher.php5" title="Maustüröffnertag" >}} in collaboration with the popular children's format Die Sendung mit der Maus / the WDR, has been cancelled owed to the global pandemic situation.

<!--
Due to the huge success of last year's event, FraLUG is participating in the Maus Türöffner Tag (Mouse Door Opener Day, sorry about the broken translation :-) ) this year once again. As in the years before, the event takes place on October 3rd in Frankfurt.
-->

![LPD](/lpd/maus.png)

The {{< tabref href="https://l-p-d.org/de/start" title="Linux Presentation Day" >}} is an event where people with little or no previous exposure to Linux have the opportunity to gain a first introduction and experience with this open source operating sytem. The aim of this event which is done in collaboration with the Westdeutscher Rundfunk (WDR), the broadcaster who created this kids' show more than forty years ago, is to also introduce children aged 6 or above to this open source operating system.

Multiple presentations will introduce the children in a suitable way to topics such as programming, using Linux and contemporary issues including Raspberry Pies, etc. In doing so, the focus is on hands-on experience rather than classroom-style teaching so that the audience can benefit the most from this. In addition, there will be demo PCs with games, learning software and special Linux distributions for kids.

Apart from this content aimed at kids there will be experts on site who can help with any questions you may have on the subject of Linux and free software in general. We plan to offer a clinic where we can assist you with any questions on installation and configuration topics - feel free to bring your laptop along!

To ensure proper organisation of the day, participation does require a registration prior to the event, done via email to maus (at) lugfrankfurt.de. Please state the name and age of participating children when registering.

### Program

The schedule for the day is currently in preparation and will be published in September. Please note that this event will last for the whole day; unfortunately a participation at individual times is not possible due to the fact that a specific piece of content depends on its predecessors.

Please note that the language of the talks and general interaction is German. While some of us do speak English, no guarantees are offered to cater for any non-German speaking participants.

### The certificate

Due to the successful participation in last year's event, the WDR has kindly sent us a certificate thanking us:

![LPD](/lpd/Maus2018.png)
